@@ -1,16 +1,32 @@
 """
-The :class:`~Graph` class can be used to draw directed or undirected graphs.
-Each graph is made up of nodes and edges and can be used to show the relations between nodes.
+Multiplex's graph visualizations use the popular `networkx <https://networkx.github.io/>`_ library.
+If you already use networkx, you can visualize networks in a handful of lines:
 
-.. image:: ../examples/exports/4-marvel.png
-   :align: center
-   :class: example
-   :width: 500
+.. code-block:: python
 
-.. note::
+	import matplotlib.pyplot as plt
+	import networkx as nx
+	from multiplex import drawable
+	viz = drawable.Drawable(plt.figure(figsize=(10, 10)))
+	G = nx.path_graph(5)
+	viz.draw_graph(G, edge_style={ 'color': 'C1' },
+	               node_style={ 'color': 'C4', 'edgecolor': 'C1', 'linewidth': 2, 's': 250 })
+	viz.show()
 
-	The graph visualization uses the `networkx` package to generate the layout of the graph.
-	Therefore it is a prerequisite to create these visualizations.
+Although Multiplex requires only the graph, you can style the nodes and the edges using the ``node_style`` and ``edge_style`` parameters.
+
+Multiplex supports both undirected and directed edges.
+Moreover, the library also supports self-connections, or edges from a node to itself.
+
+Apart from drawing nodes and edges, Multiplex is also capable of drawing names next to nodes and edges.
+These can be used, for instance, to write node names or describe the types of relations between nodes.
+
+Finally, Multiplex's graphs also support legend labels for both nodes and edges.
+
+.. warning::
+
+	The graph visualization uses the `networkx <https://networkx.github.io/>`_ package to generate the layout of the graph.
+	Therefore it is a prerequisite to have it installed before creating these visualizations.
 """
 
 import math
@@ -26,7 +42,12 @@ from text.annotation import Annotation
 
 class Graph(LabelledVisualization):
 	"""
-	The :class:`~Graph` class draws nodes and edges.
+	The :class:`~Graph` class is a general network graph that plots nodes and creates edges between them.
+	Like all visualizations, it stores a :class:`~drawable.Drawable` instance and revolves around the :func:`~Graph.draw` function.
+
+	The :class:`~Graph` class builds on the :class:`~labelled.LabelledVisualization`.
+	The reason why the :class:`~Graph` builds on that, and not the simpler :class:`~visualization.Visualization`, is that it uses the :class:`~labelled.LabelledVisualization`'s labels for node names.
+	In this way, the :class:`~Graph` automatically ensures that the node names do not overlap.
 	"""
 
 	def __init__(self, *args, **kwargs):
@@ -38,35 +59,91 @@ class Graph(LabelledVisualization):
 
 	def draw(self, G, positions=None, node_style=None, name_style=None, edge_style=None, label_style=None, *args, **kwargs):
 		"""
-		Draw the given graph.
+		Draw the given `networkx graph <https://networkx.github.io/documentation/stable/reference/classes/index.html>`_ on the :class:`~drawable.Drawable`.
 
-		Any additional arguments and keyword arguments are passed on to the :func:`networkx.spring_layout` function.
+		The method expects only a graph.
+		Differently from other visualizations, the styling options are passed on as ``dict`` arguments.
+
+		By default, this method generates the node positions using the `networkx.spring_layout <https://networkx.github.io/documentation/stable/reference/generated/networkx.drawing.layout.spring_layout.html?highlight=spring_layout#networkx.drawing.layout.spring_layout>`_ function.
+		The ``args`` and ``kwargs`` are passed on to this function to control how the graph looks.
+		However, you can provide your own node positions in the ``positions`` argument.
+
+		To draw the graph, the :class:`~Graph` draws three types of components:
+
+			1. Nodes using `matplotlib's scatter function <https://matplotlib.org/3.2.2/api/_as_gen/matplotlib.pyplot.scatter.html>`_,
+			2. Undirected edges using `matplotlib's plot function <https://matplotlib.org/3.2.2/api/_as_gen/matplotlib.pyplot.plot.html>`_ and
+			   directed edges using `matplotlib's annotate function <https://matplotlib.org/3.2.2/api/_as_gen/matplotlib.pyplot.annotate.html>`_, and
+			3. Node and edge names using :class:`~text.annotation.Annotation`.
+
+		The :class:`~Graph` automatically draws names next to nodes and edges whenever it finds a ``name`` attribute.
+		You can set the name directly on the node or edge in the graph:
+
+		.. code-block:: python
+
+			G.nodes['u']['name'] = 'node'
+			G.edges[('u', 'v')]['name'] = 'edge'
+
+		Similarly, the :class:`~Graph` adds a legend for nodes and edges whenever it finds a ``label`` attribute.
+		You can set the label directly on the node or edge in the graph:
+
+		.. code-block:: python
+
+			G.nodes['u']['label'] = 'node'
+			G.edges[('u', 'v')]['label'] = 'edge'
 
 		:param G: The networkx graph to draw.
+				  The function automatically detects whether the graph is undirected or directed and draws the edges accordingly.
 		:type G: :class:`networkx.classes.graph.Graph`
 		:param positions: The node's initial positions.
-						  If they are given, the keys should be the node names and the values tuples representing their position.
-						  Nodes without a position are generated using network'x spring layout.
+						  If you provide no positions, the function uses the `networkx.spring_layout <https://networkx.github.io/documentation/stable/reference/generated/networkx.drawing.layout.spring_layout.html?highlight=spring_layout#networkx.drawing.layout.spring_layout>`_ function to find the best position for nodes.
+						  If you provide a position for a subset of the nodes, the rest of the positions are generated automatically.
+
+						  You can provide the positions with node names as keys and their positions as values.
+						  Positions must be tuples: the x and y coordinates.
 		:type positions: dict
 		:param node_style: The general style for nodes.
-						   Keys correspond to the styling parameter and the values are the styling value.
-						   They are passed on as keyword arguments to the :func:`~graph.graph.Graph._draw_nodes` function.
-						   Individual nodes can override this style using the `style` attribute.
+			   			   The ``node_style`` accepts any styling option supported by `matplotlib's scatter function <https://matplotlib.org/3.2.2/api/_as_gen/matplotlib.pyplot.scatter.html>`_.
+
+						   You can override the general style of the nodes by giving them a ``style`` attribute:
+
+						   .. code-block:: python
+
+			   			     G.nodes['u']['style'] = { 'color': '#BB3633' }
+
+						   .. note::
+
+						     You can set the size of nodes by setting the ``s`` key in the ``node_style``.
+						     By default, the size is 100.
 		:type node_style: dict
 		:param name_style: The general style for names.
-						   Keys correspond to the styling parameter and the values are the styling value.
-						   They are passed on as keyword arguments to the :func:`~graph.graph.Graph._draw_node_names` function.
-						   Individual names can override this style using the `style` attribute.
+			   			   The ``name_style`` accepts any styling option supported by the :class:`~text.annotation.Annotation`'s :func:`~text.annotation.Annotation.draw` function.
+
+						   You can override the general style of the names by giving nodes and edges a ``name_style`` attribute:
+
+						   .. code-block:: python
+
+			   			     G.nodes['u']['name_style'] = { 'fontweight': 'bold' }
+			   			     G.edges[('u', 'v')]['name_style'] = { 'fontweight': 'bold' }
 		:type name_style: dict
 		:param edge_style: The general style for edges.
-						   Keys correspond to the styling parameter and the values are the styling value.
-						   They are passed on as keyword arguments to the :func:`~graph.graph.Graph._draw_edges` function.
-						   Individual edges can override this style using the `style` attribute.
+		 				   The ``edge_style`` accepts any styling option supported by `matplotlib's plot <https://matplotlib.org/3.2.2/api/_as_gen/matplotlib.pyplot.plot.html>`_ and `annotate <https://matplotlib.org/3.2.2/api/_as_gen/matplotlib.pyplot.annotate.html>`_ functions.
+
+						   You can override the general style of the edges by giving them a ``style`` attribute:
+
+						   .. code-block:: python
+
+						     G.edges[('u', 'v')]['style'] = { 'color': '#BB3633' }
 		:type edge_style: dict
-		:param label_style: The style of the label.
+		:param label_style: The general style for labels.
+							The ``label_style`` accepts any styling option supported by the :class:`~text.annotation.Annotation`'s :func:`~text.annotation.Annotation.draw` function.
 		:type label_style: dict or None
 
-		:return: A tuple containing the list of drawn nodes, the rendered node names, edges, and the rendered edge names.
+		:return: A tuple containing the drawn components:
+
+				 1. A list of drawn nodes as :class:`matplotlib.collections.PathCollection` instances,
+				 2. A list of rendered node names as :class:`~text.annotation.Annotation` instances,
+				 3. A list of edges as :class:`matplotlib.lines.Line2D` instances if the graph is undirected or as :class:`matplotlib.text.Annotation` if the graph is directed, and
+				 4. A list of rendered edge names as :class:`~text.annotation.Annotation` instances.
 		:rtype: tuple
 		"""
 
@@ -76,7 +153,7 @@ class Graph(LabelledVisualization):
 		edge_style = edge_style or { }
 		label_style = label_style or { }
 
-		self.drawable.axis.axis('off')
+		self.drawable.axes.axis('off')
 		spring = nx.spring_layout(G, *args, **kwargs)
 		spring.update(positions)
 		positions = spring
@@ -96,7 +173,7 @@ class Graph(LabelledVisualization):
 		"""
 		Draw the nodes onto the :class:`~drawable.Drawable`.
 
-		Any additional arguments and keyword arguments are passed on to the :func:`matplotlib.pyplot.scatter` function.
+		Any additional arguments and keyword arguments are passed on to the `matplotlib.pyplot.scatter <https://matplotlib.org/3.1.1/api/_as_gen/matplotlib.pyplot.scatter.html>`_ function.
 
 		The nodes should be given as dictionaries, whose keys are the node names.
 		The corresponding values are their positions.
@@ -108,7 +185,7 @@ class Graph(LabelledVisualization):
 		:type positions: dict
 
 		:return: A dictionary of rendered nodes.
-				 The keys are the node names and the values are :class:`matplotlib.collections.PathCollection`, representing the rendered nodes.
+				 The keys are the node names and the values are `matplotlib.collections.PathCollection <https://matplotlib.org/3.1.1/api/collections_api.html>`_, representing the rendered nodes.
 		:rtype: dict
 		"""
 
@@ -194,7 +271,7 @@ class Graph(LabelledVisualization):
 		Draw the edges connecting the given nodes.
 		Depending on whether the graph is undirected or directed, the edges are drawn with arrows.
 
-		Any additional arguments and keyword arguments are passed on to the :func:`matplotlib.pyplot.plot` function or as arrowprops.
+		Any additional arguments and keyword arguments are passed on to the `matplotlib.pyplot.plot <https://matplotlib.org/3.1.1/api/_as_gen/matplotlib.pyplot.plot.html>`_ function or as arrowprops.
 
 		:param edges: The list of edges to draw.
 					  The edges should be a list of tuples representing the source and target.
@@ -241,7 +318,7 @@ class Graph(LabelledVisualization):
 			This is done by calculating the radius of the nodes, which is where the edges should end.
 			Calculate the distance between the two centers and reduce from it the radius of the source and target nodes.
 			"""
-			ratio = util.get_aspect(self.drawable.axis)
+			ratio = util.get_aspect(self.drawable.axes)
 			angle = self._get_angle(u, v)
 			direction = self._get_direction(u, v)
 			for node, position in zip([ source, target ], [ u, v ]):
@@ -269,7 +346,7 @@ class Graph(LabelledVisualization):
 				x, y = (u[0], v[0]), (u[1], v[1])
 				rendered[(source, target)] = self.drawable.plot(x, y, zorder=-1, *args, **edge_style)[0]
 			if directed:
-				rendered[(source, target)] = self.drawable.axis.annotate('', xy=v, xytext=u,
+				rendered[(source, target)] = self.drawable.axes.annotate('', xy=v, xytext=u,
 																		 zorder=-1, arrowprops=edge_style)
 
 		return rendered
@@ -348,7 +425,7 @@ class Graph(LabelledVisualization):
 				Re-draw the annotation, this time positionally centered along the edge.
 				The rotation depends on the elevation from the source to the target node.
 				"""
-				ratio = util.get_aspect(self.drawable.axis)
+				ratio = util.get_aspect(self.drawable.axes)
 				distance = self._get_distance(u, v)
 				direction = self._get_direction(u, v)
 				angle = self._get_elevation(u, v)
@@ -409,7 +486,7 @@ class Graph(LabelledVisualization):
 		"""
 		Calculate the horizontal distance from the center of the node to where the node and the loop intersect.
 		"""
-		ratio = util.get_aspect(self.drawable.axis)
+		ratio = util.get_aspect(self.drawable.axes)
 		x1 = math.sqrt( ( (radius[0]) ** 2 * radius[1] ** 2 - (radius[0]) ** 2 * d1 ** 2 ) / ( (radius[0]) ** 2 ) ) * ratio
 
 		"""
@@ -445,7 +522,7 @@ class Graph(LabelledVisualization):
 				arrowprops['headlength'] = arrowprops.get('headwidth') * 0.75
 			xy = ( x[-1], y[-1] )
 			xytext = ( x[-2], y[-2] )
-			arrow = self.drawable.axis.annotate('', xy=xy, xytext=xytext,
+			arrow = self.drawable.axes.annotate('', xy=xy, xytext=xytext,
 												zorder=-1, arrowprops=arrowprops)
 
 
@@ -464,8 +541,6 @@ class Graph(LabelledVisualization):
 		:type label_style: dict
 		"""
 
-		drawn = [ ]
-
 		for node in nodes:
 			"""
 			Go through each node and look for the label.
@@ -475,9 +550,6 @@ class Graph(LabelledVisualization):
 			if 'label' in nodes[node]:
 				label = nodes[node]['label']
 
-				if label in drawn:
-					continue
-
 				default_style = dict(**kwargs)
 				default_style.update(nodes[node].get('style', { }))
 
@@ -485,12 +557,10 @@ class Graph(LabelledVisualization):
 				The y-axis change when drawing points.
 				Therefore save the y-limit and re-set it after drawing.
 				"""
-				ylim = self.drawable.axis.get_ylim()
+				ylim = self.drawable.axes.get_ylim()
 				self.drawable.legend.draw_point(label, label_style=label_style,
 												*args, **default_style)
-				self.drawable.axis.set_ylim(ylim)
-
-				drawn.append(label)
+				self.drawable.axes.set_ylim(ylim)
 
 	def _draw_edge_labels(self, edges, directed, label_style, *args, **kwargs):
 		"""
@@ -507,8 +577,6 @@ class Graph(LabelledVisualization):
 		:type label_style: dict
 		"""
 
-		drawn = [ ]
-
 		for edge in edges:
 			"""
 			Go through each edge and look for the label.
@@ -518,9 +586,6 @@ class Graph(LabelledVisualization):
 			if 'label' in edges[edge]:
 				label = edges[edge]['label']
 
-				if label in drawn:
-					continue
-
 				default_style = dict(**kwargs)
 				default_style.update(edges[edge].get('style', { }))
 				if directed:
@@ -529,7 +594,6 @@ class Graph(LabelledVisualization):
 				else:
 					self.drawable.legend.draw_line(label, label_style=label_style,
 													*args, **default_style)
-				drawn.append(label)
 
 	def _get_distance(self, u, v):
 		"""
@@ -605,14 +669,14 @@ class Graph(LabelledVisualization):
 		if xdiff == 0:
 			return math.pi / 2.
 
-		ratio = util.get_aspect(self.drawable.axis)
+		ratio = util.get_aspect(self.drawable.axes)
 		ydiff = (v[1] - u[1]) * ratio
 
 		return math.atan(ydiff / xdiff)
 
 	def _get_radius(self, node, s):
 		"""
-		Get the radius of the given node in terms of the data axis.
+		Get the radius of the given node in terms of the data axes.
 		By default, the radius `s` is 100, but it can be overriden using the node's `style` attribute.
 
 		.. note::
@@ -625,15 +689,15 @@ class Graph(LabelledVisualization):
 				  It may be overwritten with the node's own radius.
 		:type s: float
 
-		:return: The radius of the node in terms of the data axis.
+		:return: The radius of the node in terms of the data axes.
 				 Two radii are provided: the x- and y-radii.
 				 This is because scatter points always look like circles, even when the display or data ratios are not equal.
 				 Whn the display or data ratios are not equal, the point is actually an ellipse so that it still looks like a circle.
 		:rtype: tuple
 		"""
 
-		origin = self.drawable.axis.transData.inverted().transform((0, 0))
+		origin = self.drawable.axes.transData.inverted().transform((0, 0))
 
-		x = (self.drawable.axis.transData.inverted().transform((s ** 0.5, 0))[0] - origin[0])/2.
-		y = (self.drawable.axis.transData.inverted().transform((0, s ** 0.5))[1] - origin[1])/2.
+		x = (self.drawable.axes.transData.inverted().transform((s ** 0.5, 0))[0] - origin[0])/2.
+		y = (self.drawable.axes.transData.inverted().transform((0, s ** 0.5))[1] - origin[1])/2.
 		return (x, y)
